@@ -1,12 +1,59 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
-""" Envisage package Copyright 2003-2007 Enthought, Inc. """
+
+"""
+Primary API for envisage
+
+Interfaces
+----------
+
+- :class:`~.IApplication`
+- :class:`~.IExtensionPoint`
+- :class:`~.IExtensionPointUser`
+- :class:`~.IExtensionProvider`
+- :class:`~.IExtensionRegistry`
+- :class:`~.IImportManager`
+- :class:`~.IPlugin`
+- :class:`~.IPluginActivator`
+- :class:`~.IPluginManager`
+- :class:`~.IServiceRegistry`
+
+Application, plugin and related classes
+------------------------------------------
+- :class:`~.Application`
+- :class:`~.CorePlugin`
+- :class:`~.EggPluginManager`
+- :class:`~.ExtensionPoint`
+- :func:`~.contributes_to`
+- :class:`~.ExtensionPointBinding`
+- :func:`~.bind_extension_point`
+- :class:`~.ExtensionProvider`
+- :class:`~.ExtensionPointChangedEvent`
+- :class:`~.ImportManager`
+- :class:`~.Plugin`
+- :class:`~.PluginActivator`
+- :class:`~.PluginExtensionRegistry`
+- :class:`~.PluginManager`
+- :class:`~.ProviderExtensionRegistry`
+- :class:`~.Service`
+- :class:`~.ServiceOffer`
+- :class:`~.ServiceRegistry`
+
+Exceptions
+----------
+
+- :class:`~.NoSuchServiceError`
+- :class:`~.UnknownExtension`
+- :class:`~.UnknownExtensionPoint`
+
+"""
 
 from .i_application import IApplication
 from .i_extension_point import IExtensionPoint
@@ -20,12 +67,14 @@ from .i_plugin_manager import IPluginManager
 from .i_service_registry import IServiceRegistry
 
 from .application import Application
-from .category import Category
-from .class_load_hook import ClassLoadHook
+from .core_plugin import CorePlugin
 from .egg_plugin_manager import EggPluginManager
 from .extension_registry import ExtensionRegistry
 from .extension_point import ExtensionPoint, contributes_to
-from .extension_point_binding import ExtensionPointBinding, bind_extension_point
+from .extension_point_binding import (
+    ExtensionPointBinding,
+    bind_extension_point,
+)
 from .extension_provider import ExtensionProvider
 from .extension_point_changed_event import ExtensionPointChangedEvent
 from .import_manager import ImportManager
@@ -37,9 +86,5 @@ from .provider_extension_registry import ProviderExtensionRegistry
 from .service import Service
 from .service_offer import ServiceOffer
 from .service_registry import NoSuchServiceError, ServiceRegistry
-from .twisted_application import TwistedApplication
 from .unknown_extension import UnknownExtension
 from .unknown_extension_point import UnknownExtensionPoint
-
-
-#### EOF ######################################################################
