@@ -1,16 +1,18 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ An extensible, pluggable, application. """
 
 
 # Standard library imports.
-import logging, os
+import logging
+import os
 
 # Enthought library imports.
 from traits.etsconfig.api import ETSConfig
@@ -45,59 +47,59 @@ class Application(HasTraits):
 
     #### 'IApplication' interface #############################################
 
-    # The application's globally unique identifier.
+    #: The application's globally unique identifier.
     id = Str
 
-    # The name of a directory (created for you) to which the application can
-    # read and write non-user accessible data, i.e. configuration information,
-    # preferences, etc.
+    #: The name of a directory (created for you) to which the application can
+    #: read and write non-user accessible data, i.e. configuration information,
+    #: preferences, etc.
     home = Str
 
-    # The name of a directory (created for you upon access) to which the
-    # application can read and write user-accessible data, e.g. projects created
-    # by the user.
+    #: The name of a directory (created for you upon access) to which the
+    #: application can read and write user-accessible data, e.g. projects
+    #: created by the user.
     user_data = Str
 
-    # The root preferences node.
+    #: The root preferences node.
     preferences = Instance(IPreferences)
 
     #### Events ####
 
-    # Fired when the application is starting.
+    #: Fired when the application is starting.
     starting = VetoableEvent(ApplicationEvent)
 
-    # Fired when all plugins have been started.
+    #: Fired when all plugins have been started.
     started = Event(ApplicationEvent)
 
-    # Fired when the application is stopping.
+    #: Fired when the application is stopping.
     stopping = VetoableEvent(ApplicationEvent)
 
-    # Fired when all plugins have been stopped.
+    #: Fired when all plugins have been stopped.
     stopped = Event(ApplicationEvent)
 
     #### 'IPluginManager' interface ###########################################
 
     #### Events ####
 
-    # Fired when a plugin has been added.
-    plugin_added = Delegate('plugin_manager', modify=True)
+    #: Fired when a plugin has been added.
+    plugin_added = Delegate("plugin_manager", modify=True)
 
-    # Fired when a plugin has been removed.
-    plugin_removed = Delegate('plugin_manager', modify=True)
+    #: Fired when a plugin has been removed.
+    plugin_removed = Delegate("plugin_manager", modify=True)
 
     #### 'Application' interface ##############################################
 
     # These traits allow application developers to build completely different
     # styles of extensible application. It allows Envisage to be used as a
     # framework for frameworks ;^)
-    #
-    # The extension registry.
+
+    #: The extension registry.
     extension_registry = Instance(IExtensionRegistry)
 
-    # The plugin manager (starts and stops plugins etc).
+    #: The plugin manager (starts and stops plugins etc).
     plugin_manager = Instance(IPluginManager)
 
-    # The service registry.
+    #: The service registry.
     service_registry = Instance(IServiceRegistry)
 
     #### Private interface ####################################################
@@ -120,7 +122,7 @@ class Application(HasTraits):
 
         """
 
-        super(Application, self).__init__(**traits)
+        super().__init__(**traits)
 
         # fixme: We have to initialize the application home here (i.e. we can't
         # wait until the 'home' trait is accessed) because the scoped
@@ -160,9 +162,7 @@ class Application(HasTraits):
     def _user_data_default(self):
         """ Trait initializer. """
 
-        user_data = os.path.join(
-            ETSConfig.user_data, self.id
-        )
+        user_data = os.path.join(ETSConfig.user_data, self.id)
 
         # Make sure it exists!
         if not os.path.exists(user_data):
@@ -224,7 +224,9 @@ class Application(HasTraits):
 
         return self.extension_registry.get_extension_points()
 
-    def remove_extension_point_listener(self,listener,extension_point_id=None):
+    def remove_extension_point_listener(
+        self, listener, extension_point_id=None
+    ):
         """ Remove a listener for extensions being added/removed. """
 
         self.extension_registry.remove_extension_point_listener(
@@ -294,7 +296,7 @@ class Application(HasTraits):
         # fixme: This method is notionally on the 'IPluginManager' interface
         # but that interface knows nothing about the vetoable events etc and
         # hence doesn't have a return value.
-        logger.debug('---------- application starting ----------')
+        logger.debug("---------- application starting ----------")
 
         # Lifecycle event.
         self.starting = event = self._create_application_event()
@@ -306,10 +308,10 @@ class Application(HasTraits):
             # Lifecycle event.
             self.started = self._create_application_event()
 
-            logger.debug('---------- application started ----------')
+            logger.debug("---------- application started ----------")
 
         else:
-            logger.debug('---------- application start vetoed ----------')
+            logger.debug("---------- application start vetoed ----------")
 
         return not event.veto
 
@@ -328,7 +330,7 @@ class Application(HasTraits):
         # fixme: This method is notionally on the 'IPluginManager' interface
         # but that interface knows nothing about the vetoable events etc and
         # hence doesn't have a return value.
-        logger.debug('---------- application stopping ----------')
+        logger.debug("---------- application stopping ----------")
 
         # Lifecycle event.
         self.stopping = event = self._create_application_event()
@@ -343,10 +345,10 @@ class Application(HasTraits):
             # Lifecycle event.
             self.stopped = self._create_application_event()
 
-            logger.debug('---------- application stopped ----------')
+            logger.debug("---------- application stopped ----------")
 
         else:
-            logger.debug('---------- application stop vetoed ----------')
+            logger.debug("---------- application stop vetoed ----------")
 
         return not event.veto
 
@@ -359,7 +361,9 @@ class Application(HasTraits):
     # 'IServiceRegistry' interface.
     ###########################################################################
 
-    def get_required_service(self, protocol, query='', minimize='',maximize=''):
+    def get_required_service(
+        self, protocol, query="", minimize="", maximize=""
+    ):
         """ Return the service that matches the specified query.
 
         Raise a 'NoSuchServiceError' exception if no such service exists.
@@ -372,7 +376,7 @@ class Application(HasTraits):
 
         return service
 
-    def get_service(self, protocol, query='', minimize='', maximize=''):
+    def get_service(self, protocol, query="", minimize="", maximize=""):
         """ Return at most one service that matches the specified query. """
 
         service = self.service_registry.get_service(
@@ -391,7 +395,7 @@ class Application(HasTraits):
 
         return self.service_registry.get_service_properties(service_id)
 
-    def get_services(self, protocol, query='', minimize='', maximize=''):
+    def get_services(self, protocol, query="", minimize="", maximize=""):
         """ Return all services that match the specified query. """
 
         services = self.service_registry.get_services(
@@ -511,5 +515,3 @@ class Application(HasTraits):
             os.makedirs(ETSConfig.application_home)
 
         return
-
-#### EOF ######################################################################
