@@ -1,16 +1,21 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ A plugin manager that gets its plugins from Eggs. """
 
 
 # Standard library imports.
-import logging, pkg_resources, re
+import logging
+import re
+
+# 3rd party imports.
+import pkg_resources
 
 # Enthought library imports.
 from traits.api import Instance, List, Str
@@ -42,7 +47,7 @@ class EggPluginManager(PluginManager):
     """
 
     # Entry point Id.
-    PLUGINS = 'envisage.plugins'
+    PLUGINS = "envisage.plugins"
 
     #### 'EggPluginManager' interface #########################################
 
@@ -74,12 +79,14 @@ class EggPluginManager(PluginManager):
         """ Trait initializer. """
 
         plugins = []
-        for ep in get_entry_points_in_egg_order(self.working_set, self.PLUGINS):
+        for ep in get_entry_points_in_egg_order(
+            self.working_set, self.PLUGINS
+        ):
             if self._is_included(ep.name) and not self._is_excluded(ep.name):
                 plugin = self._create_plugin_from_ep(ep)
                 plugins.append(plugin)
 
-        logger.debug('egg plugin manager found plugins <%s>', plugins)
+        logger.debug("egg plugin manager found plugins <%s>", plugins)
 
         return plugins
 
@@ -90,15 +97,15 @@ class EggPluginManager(PluginManager):
     def _create_plugin_from_ep(self, ep):
         """ Create a plugin from an extension point. """
 
-        klass  = ep.load()
+        klass = ep.load()
         plugin = klass(application=self.application)
 
         # Warn if the entry point is an old-style one where the LHS didn't have
         # to be the same as the plugin Id.
         if ep.name != plugin.id:
             logger.warning(
-                'entry point name <%s> should be the same as the '
-                'plugin id <%s>' % (ep.name, plugin.id)
+                "entry point name <%s> should be the same as the "
+                "plugin id <%s>" % (ep.name, plugin.id)
             )
 
         return plugin
@@ -136,5 +143,3 @@ class EggPluginManager(PluginManager):
                 return True
 
         return False
-
-#### EOF ######################################################################
