@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ The interface for extension registries. """
 
@@ -66,7 +67,9 @@ class IExtensionRegistry(Interface):
 
         """
 
-    def remove_extension_point_listener(self,listener,extension_point_id=None):
+    def remove_extension_point_listener(
+        self, listener, extension_point_id=None
+    ):
         """ Remove a listener for extensions being added or removed.
 
         Raise a 'ValueError' if the listener does not exist.
@@ -85,5 +88,3 @@ class IExtensionRegistry(Interface):
         """ Set the extensions contributed to an extension point.
 
         """
-
-#### EOF ######################################################################
