@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ The plugin interface. """
 
@@ -19,25 +20,25 @@ from .i_plugin_activator import IPluginActivator
 class IPlugin(Interface):
     """ The plugin interface. """
 
-    # The activator used to start and stop the plugin.
+    #: The activator used to start and stop the plugin.
     activator = Instance(IPluginActivator)
 
-    # The application that the plugin is part of.
-    application = Instance('envisage.api.IApplication')
+    #: The application that the plugin is part of.
+    application = Instance("envisage.api.IApplication")
 
-    # The name of a directory (created for you) that the plugin can read and
-    # write to at will.
+    #: The name of a directory (created for you) that the plugin can read and
+    #: write to at will.
     home = Str
 
-    # The plugin's unique identifier.
-    #
-    # Where 'unique' technically means 'unique within the plugin manager', but
-    # since the chances are that you will want to include plugins from external
-    # sources, this really means 'globally unique'! Using the Python package
-    # path might be useful here. e.g. 'envisage'.
+    #: The plugin's unique identifier.
+    #:
+    #: Where 'unique' technically means 'unique within the plugin manager', but
+    #: since the chances are that you will want to include plugins from
+    #: external sources, this really means 'globally unique'! Using the Python
+    #: package path might be useful here. e.g. 'envisage'.
     id = Str
 
-    # The plugin's name (suitable for displaying to the user).
+    #: The plugin's name (suitable for displaying to the user).
     name = Str
 
     def start(self):
@@ -59,5 +60,3 @@ class IPlugin(Interface):
           application.stop_plugin(plugin)
 
         """
-
-#### EOF ######################################################################
