@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ The default import manager implementation. """
 
@@ -33,16 +34,16 @@ class ImportManager(HasTraits):
     def import_symbol(self, symbol_path):
         """ Import the symbol defined by the specified symbol path. """
 
-        if ':' in symbol_path:
-            module_name, symbol_name = symbol_path.split(':')
+        if ":" in symbol_path:
+            module_name, symbol_name = symbol_path.split(":")
 
             module = self._import_module(module_name)
             symbol = eval(symbol_name, module.__dict__)
 
         else:
-            components = symbol_path.split('.')
+            components = symbol_path.split(".")
 
-            module_name = '.'.join(components[:-1])
+            module_name = ".".join(components[:-1])
             symbol_name = components[-1]
 
             module = __import__(
@@ -72,10 +73,8 @@ class ImportManager(HasTraits):
 
         module = __import__(module_name)
 
-        components = module_name.split('.')
+        components = module_name.split(".")
         for component in components[1:]:
             module = getattr(module, component)
 
         return module
-
-#### EOF ######################################################################
