@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ This module provides a plugin which adds an EventManager to application.
 
@@ -16,23 +17,21 @@ of the application to the created event manager.
 
 # Enthought library imports.
 from envisage.api import Plugin, ServiceOffer
-from traits.api import List, Any
+from traits.api import List
 
 
 class EventManagerPlugin(Plugin):
     """ Plugin to add event manager to the application. """
 
-    id = 'envisage.event_manager'
+    id = "envisage.event_manager"
 
-    SERVICE_OFFERS = 'envisage.service_offers'
+    SERVICE_OFFERS = "envisage.service_offers"
     service_offers = List(contributes_to=SERVICE_OFFERS)
 
     def _service_offers_default(self):
         from encore.events.api import BaseEventManager, get_event_manager
 
         evt_mgr_service_offer = ServiceOffer(
-            protocol   = BaseEventManager,
-            factory    = get_event_manager,
+            protocol=BaseEventManager, factory=get_event_manager,
         )
         return [evt_mgr_service_offer]
-
