@@ -1,30 +1,24 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 
 import contextlib
 import os
-try:
-    # Python 3: mock available in std. lib.
-    from unittest import mock
-except ImportError:
-    # Python 2: use 3rd party mock library
-    import mock
 import shutil
 import tempfile
 import unittest
+from unittest import mock
 import warnings
 
 from traits.api import List
 
-from envisage._compat import STRING_BASE_CLASS
-from envisage.api import Application, Plugin
-from envisage.core_plugin import CorePlugin
+from envisage.api import Application, CorePlugin, Plugin
 from envisage.tests.ets_config_patcher import ETSConfigPatcher
 
 # Skip these tests unless ipykernel is available.
@@ -36,14 +30,19 @@ else:
     ipykernel_available = True
 
 if ipykernel_available:
-    from envisage.plugins.ipython_kernel.internal_ipkernel import (
-        InternalIPKernel)
+    from envisage.plugins.ipython_kernel.api import (
+        InternalIPKernel,
+        IPythonKernelPlugin,
+        IPYTHON_KERNEL_PROTOCOL,
+    )
     from envisage.plugins.ipython_kernel.ipython_kernel_plugin import (
-        IPYTHON_KERNEL_PROTOCOL, IPYTHON_NAMESPACE, IPythonKernelPlugin)
+        IPYTHON_NAMESPACE,
+    )
 
 
-@unittest.skipUnless(ipykernel_available,
-                     "skipping tests that require the ipykernel package")
+@unittest.skipUnless(
+    ipykernel_available, "skipping tests that require the ipykernel package"
+)
 class TestIPythonKernelPlugin(unittest.TestCase):
     def setUp(self):
         ets_config_patcher = ETSConfigPatcher()
@@ -69,7 +68,8 @@ class TestIPythonKernelPlugin(unittest.TestCase):
     def test_import_from_api(self):
         # Regression test for enthought/envisage#108
         from envisage.plugins.ipython_kernel.api import IPYTHON_KERNEL_PROTOCOL
-        self.assertIsInstance(IPYTHON_KERNEL_PROTOCOL, STRING_BASE_CLASS)
+
+        self.assertIsInstance(IPYTHON_KERNEL_PROTOCOL, str)
 
     def test_kernel_service(self):
         # See that we can get the IPython kernel service when the plugin is
@@ -88,7 +88,7 @@ class TestIPythonKernelPlugin(unittest.TestCase):
             kernel_namespace = List(contributes_to=IPYTHON_NAMESPACE)
 
             def _kernel_namespace_default(self):
-                return [('y', 'hi')]
+                return [("y", "hi")]
 
         plugins = [
             IPythonKernelPlugin(init_ipkernel=True),
@@ -97,8 +97,8 @@ class TestIPythonKernelPlugin(unittest.TestCase):
 
         with self.running_app(plugins=plugins) as app:
             kernel = app.get_service(IPYTHON_KERNEL_PROTOCOL)
-            self.assertIn('y', kernel.namespace)
-            self.assertEqual(kernel.namespace['y'], 'hi')
+            self.assertIn("y", kernel.namespace)
+            self.assertEqual(kernel.namespace["y"], "hi")
 
     def test_get_service_twice(self):
         with self.running_app() as app:
@@ -114,13 +114,11 @@ class TestIPythonKernelPlugin(unittest.TestCase):
 
         class TrackingInternalIPKernel(internal_ipkernel.InternalIPKernel):
             def __init__(self, *args, **kwargs):
-                super(TrackingInternalIPKernel, self).__init__(*args, **kwargs)
+                super().__init__(*args, **kwargs)
                 kernel_instances.append(self)
 
         patcher = mock.patch.object(
-            internal_ipkernel,
-            "InternalIPKernel",
-            TrackingInternalIPKernel,
+            internal_ipkernel, "InternalIPKernel", TrackingInternalIPKernel,
         )
 
         with patcher:
@@ -143,13 +141,11 @@ class TestIPythonKernelPlugin(unittest.TestCase):
 
         class TrackingInternalIPKernel(internal_ipkernel.InternalIPKernel):
             def __init__(self, *args, **kwargs):
-                super(TrackingInternalIPKernel, self).__init__(*args, **kwargs)
+                super().__init__(*args, **kwargs)
                 kernel_instances.append(self)
 
         patcher = mock.patch.object(
-            internal_ipkernel,
-            "InternalIPKernel",
-            TrackingInternalIPKernel,
+            internal_ipkernel, "InternalIPKernel", TrackingInternalIPKernel,
         )
 
         with patcher:
@@ -169,7 +165,8 @@ class TestIPythonKernelPlugin(unittest.TestCase):
                 app.get_service(IPYTHON_KERNEL_PROTOCOL)
 
         matching_messages = [
-            msg for msg in warn_msgs
+            msg
+            for msg in warn_msgs
             if isinstance(msg.message, DeprecationWarning)
             if "kernel will be initialized" in str(msg.message)
         ]
@@ -190,7 +187,7 @@ class TestIPythonKernelPlugin(unittest.TestCase):
         if plugins is None:
             plugins = [IPythonKernelPlugin(init_ipkernel=True)]
 
-        app = Application(plugins=[CorePlugin()] + plugins, id='test')
+        app = Application(plugins=[CorePlugin()] + plugins, id="test")
         app.start()
         try:
             yield app
