@@ -1,3 +1,12 @@
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """ A resource protocol for a local file system. """
 
 
@@ -26,7 +35,7 @@ class FileResourceProtocol(HasTraits):
         # Opened in binary mode to be consistent with package resources. This
         # means, for example, that line-endings will not be converted.
         try:
-            f = open(address, 'rb')
+            f = open(address, "rb")
 
         except IOError as e:
             if e.errno == errno.ENOENT:
@@ -36,5 +45,3 @@ class FileResourceProtocol(HasTraits):
                 raise
 
         return f
-
-#### EOF ######################################################################
