@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ A resource protocol for HTTP documents. """
 
@@ -27,16 +28,15 @@ class HTTPResourceProtocol(HasTraits):
     def file(self, address):
         """ Return a readable file-like object for the specified address. """
 
-        # Do the import here 'cos I'm not sure how much this will actually
+        # Do the imports here 'cos I'm not sure how much this will actually
         # be used.
-        from .._compat import urlopen, HTTPError
+        from urllib.error import HTTPError
+        from urllib.request import urlopen
 
         try:
-            f = urlopen('http://' + address)
+            f = urlopen("http://" + address)
 
         except HTTPError:
-            raise NoSuchResourceError('http:://' + address)
+            raise NoSuchResourceError("http:://" + address)
 
         return f
-
-#### EOF ######################################################################
