@@ -1,16 +1,20 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ A resource protocol for package resources. """
 
 
 # Standard library imports.
-import errno, pkg_resources
+import errno
+
+# 3rd party imports.
+import pkg_resources
 
 # Enthought library imports.
 from traits.api import HasTraits, provides
@@ -44,10 +48,10 @@ class PackageResourceProtocol(HasTraits):
     def file(self, address):
         """ Return a readable file-like object for the specified address. """
 
-        first_forward_slash = address.index('/')
+        first_forward_slash = address.index("/")
 
-        package       = address[:first_forward_slash]
-        resource_name = address[first_forward_slash+1:]
+        package = address[:first_forward_slash]
+        resource_name = address[first_forward_slash + 1:]
 
         try:
             f = pkg_resources.resource_stream(package, resource_name)
@@ -63,5 +67,3 @@ class PackageResourceProtocol(HasTraits):
             raise NoSuchResourceError(address)
 
         return f
-
-#### EOF ######################################################################
