@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ A trait type used to access services. """
 
@@ -33,11 +34,11 @@ class Service(TraitType):
     ###########################################################################
 
     def __init__(
-        self, protocol=None, query='', minimize='', maximize='', **metadata
+        self, protocol=None, query="", minimize="", maximize="", **metadata
     ):
         """ Constructor. """
 
-        super(Service, self).__init__(**metadata)
+        super().__init__(**metadata)
 
         # The protocol that the service must provide.
         self._protocol = protocol
@@ -53,6 +54,10 @@ class Service(TraitType):
 
         return
 
+    def __repr__(self):
+        """ String representation of a Service object """
+        return "Service(protocol={!r})".format(self._protocol)
+
     ###########################################################################
     # 'TraitType' interface.
     ###########################################################################
@@ -62,7 +67,6 @@ class Service(TraitType):
 
         service_registry = self._get_service_registry(obj)
 
-
         obj = service_registry.get_service(
             self._protocol, self._query, self._minimize, self._maximize
         )
@@ -72,7 +76,7 @@ class Service(TraitType):
     def set(self, obj, name, value):
         """ Trait type setter. """
 
-        raise SystemError('Service traits cannot be set')
+        raise SystemError("Service traits cannot be set")
 
     ###########################################################################
     # Private interface.
@@ -81,15 +85,13 @@ class Service(TraitType):
     def _get_service_registry(self, obj):
         """ Return the service registry in effect for an object. """
 
-        service_registry = getattr(obj, 'service_registry', None)
+        service_registry = getattr(obj, "service_registry", None)
         if service_registry is None:
             raise ValueError(
-                'The "Service" trait type can only be used within objects ' \
-                'that have a reference to a service registry via their ' \
-                '"service_registry" trait. \n' \
-                'Object %s\nService protocol %s' % (obj, self._protocol)
+                'The "Service" trait type can only be used within objects '
+                "that have a reference to a service registry via their "
+                '"service_registry" trait. \n'
+                "Object %s\nService protocol %s" % (obj, self._protocol)
             )
 
         return service_registry
-
-#### EOF ######################################################################
