@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ The 'Banana' plugin """
 
@@ -16,10 +17,10 @@ from traits.api import Bool
 class BananaPlugin(Plugin):
     """ The 'Banana' plugin """
 
-    #### 'IPlugin' protocol ####################################################
+    #### 'IPlugin' protocol ###################################################
 
     # The plugin's unique identifier.
-    id = 'banana'
+    id = "banana"
 
     def start(self):
         """ Start the plugin. """
@@ -37,9 +38,7 @@ class BananaPlugin(Plugin):
 
         return
 
-    #### 'BananaPlugin' protocol ###############################################
+    #### 'BananaPlugin' protocol ##############################################
 
     started = Bool(False)
     stopped = Bool(False)
-
-#### EOF ######################################################################
