@@ -1,19 +1,21 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ Tests for extension points. """
 
+# Standard library imports.
+import unittest
 
 # Enthought library imports.
 from envisage.api import Application, ExtensionPoint
 from envisage.api import ExtensionRegistry
 from traits.api import HasTraits, Int, List, TraitError
-from traits.testing.unittest_tools import unittest
 
 
 class TestBase(HasTraits):
@@ -49,14 +51,14 @@ class ExtensionPointTestCase(unittest.TestCase):
         registry = self.registry
 
         # Add an extension point.
-        registry.add_extension_point(self._create_extension_point('my.ep'))
+        registry.add_extension_point(self._create_extension_point("my.ep"))
 
         # Set the extensions.
-        registry.set_extensions('my.ep', 'xxx')
+        registry.set_extensions("my.ep", "xxx")
 
         # Declare a class that consumes the extension.
         class Foo(HasTraits):
-            x = ExtensionPoint(List(Int), id='my.ep')
+            x = ExtensionPoint(List(Int), id="my.ep")
 
         # We should get an exception because the object does not have an
         # 'extension_registry' trait.
@@ -70,11 +72,11 @@ class ExtensionPointTestCase(unittest.TestCase):
         registry = self.registry
 
         # Add an extension point.
-        registry.add_extension_point(self._create_extension_point('my.ep'))
+        registry.add_extension_point(self._create_extension_point("my.ep"))
 
         # Declare a class that consumes the extension.
         class Foo(TestBase):
-            x = ExtensionPoint(id='my.ep')
+            x = ExtensionPoint(id="my.ep")
 
             def _x_changed(self):
                 """ Static trait change handler. """
@@ -88,11 +90,11 @@ class ExtensionPointTestCase(unittest.TestCase):
         ExtensionPoint.connect_extension_point_traits(f)
 
         # Set the extensions.
-        registry.set_extensions('my.ep', [42, 'a string', True])
+        registry.set_extensions("my.ep", [42, "a string", True])
 
         # Make sure that instances of the class pick up the extensions.
         self.assertEqual(3, len(f.x))
-        self.assertEqual([42, 'a string', True],  f.x)
+        self.assertEqual([42, "a string", True], f.x)
 
         # Make sure the trait change handler was called.
         self.assertTrue(f.x_changed_called)
@@ -104,34 +106,59 @@ class ExtensionPointTestCase(unittest.TestCase):
         ExtensionPoint.disconnect_extension_point_traits(f)
 
         # Set the extensions.
-        registry.set_extensions('my.ep', [98, 99, 100])
+        registry.set_extensions("my.ep", [98, 99, 100])
 
         # Make sure the trait change handler was *not* called.
         self.assertEqual(False, f.x_changed_called)
 
+    def test_mutate_extension_point_no_effect(self):
+        """ Extension point is recomputed so mutation has no effect. """
+
+        registry = self.registry
+
+        # Add an extension point.
+        registry.add_extension_point(self._create_extension_point("my.ep"))
+
+        # Set the extensions.
+        registry.set_extensions("my.ep", [1, 2, 3])
+
+        # Declare a class that consumes the extension.
+        class Foo(TestBase):
+            x = ExtensionPoint(List(Int), id="my.ep")
+
+        # when
+        f = Foo()
+        f.x.append(42)
+
+        # then
+        # The registry is not changed, and the extension point is still the
+        # same as before
+        self.assertEqual(registry.get_extensions("my.ep"), [1, 2, 3])
+        self.assertEqual(f.x, [1, 2, 3])
+
     def test_untyped_extension_point(self):
         """ untyped extension point """
 
         registry = self.registry
 
         # Add an extension point.
-        registry.add_extension_point(self._create_extension_point('my.ep'))
+        registry.add_extension_point(self._create_extension_point("my.ep"))
 
         # Set the extensions.
-        registry.set_extensions('my.ep', [42, 'a string', True])
+        registry.set_extensions("my.ep", [42, "a string", True])
 
         # Declare a class that consumes the extension.
         class Foo(TestBase):
-            x = ExtensionPoint(id='my.ep')
+            x = ExtensionPoint(id="my.ep")
 
         # Make sure that instances of the class pick up the extensions.
         f = Foo()
         self.assertEqual(3, len(f.x))
-        self.assertEqual([42, 'a string', True],  f.x)
+        self.assertEqual([42, "a string", True], f.x)
 
         g = Foo()
         self.assertEqual(3, len(g.x))
-        self.assertEqual([42, 'a string', True],  g.x)
+        self.assertEqual([42, "a string", True], g.x)
 
     def test_typed_extension_point(self):
         """ typed extension point """
@@ -139,14 +166,14 @@ class ExtensionPointTestCase(unittest.TestCase):
         registry = self.registry
 
         # Add an extension point.
-        registry.add_extension_point(self._create_extension_point('my.ep'))
+        registry.add_extension_point(self._create_extension_point("my.ep"))
 
         # Set the extensions.
-        registry.set_extensions('my.ep', [42, 43, 44])
+        registry.set_extensions("my.ep", [42, 43, 44])
 
         # Declare a class that consumes the extension.
         class Foo(TestBase):
-            x = ExtensionPoint(List(Int), id='my.ep')
+            x = ExtensionPoint(List(Int), id="my.ep")
 
         # Make sure that instances of the class pick up the extensions.
         f = Foo()
@@ -163,14 +190,14 @@ class ExtensionPointTestCase(unittest.TestCase):
         registry = self.registry
 
         # Add an extension point.
-        registry.add_extension_point(self._create_extension_point('my.ep'))
+        registry.add_extension_point(self._create_extension_point("my.ep"))
 
         # Set the extensions.
-        registry.set_extensions('my.ep', 'xxx')
+        registry.set_extensions("my.ep", "xxx")
 
         # Declare a class that consumes the extension.
         class Foo(TestBase):
-            x = ExtensionPoint(List(Int), id='my.ep')
+            x = ExtensionPoint(List(Int), id="my.ep")
 
         # Make sure we get a trait error because the type of the extension
         # doesn't match that of the extension point.
@@ -194,18 +221,18 @@ class ExtensionPointTestCase(unittest.TestCase):
         registry = self.registry
 
         # Add an extension point.
-        registry.add_extension_point(self._create_extension_point('my.ep'))
+        registry.add_extension_point(self._create_extension_point("my.ep"))
 
         # Declare a class that consumes the extension.
         class Foo(TestBase):
-            x = ExtensionPoint(id='my.ep')
+            x = ExtensionPoint(id="my.ep")
 
         # Make sure that when we set the trait the extension registry gets
         # updated.
         f = Foo()
         f.x = [42]
 
-        self.assertEqual([42], registry.get_extensions('my.ep'))
+        self.assertEqual([42], registry.get_extensions("my.ep"))
 
     def test_set_typed_extension_point(self):
         """ set typed extension point """
@@ -213,31 +240,31 @@ class ExtensionPointTestCase(unittest.TestCase):
         registry = self.registry
 
         # Add an extension point.
-        registry.add_extension_point(self._create_extension_point('my.ep'))
+        registry.add_extension_point(self._create_extension_point("my.ep"))
 
         # Declare a class that consumes the extension.
         class Foo(TestBase):
-            x = ExtensionPoint(List(Int), id='my.ep')
+            x = ExtensionPoint(List(Int), id="my.ep")
 
         # Make sure that when we set the trait the extension registry gets
         # updated.
         f = Foo()
         f.x = [42]
 
-        self.assertEqual([42], registry.get_extensions('my.ep'))
+        self.assertEqual([42], registry.get_extensions("my.ep"))
 
     def test_extension_point_str_representation(self):
         """ test the string representation of the extension point """
-        ep_repr = "ExtensionPoint(id={})"
-        ep = self._create_extension_point('my.ep')
-        self.assertEqual(ep_repr.format('my.ep'), str(ep))
-        self.assertEqual(ep_repr.format('my.ep'), repr(ep))
+        ep_repr = "ExtensionPoint(id={!r})"
+        ep = self._create_extension_point("my.ep")
+        self.assertEqual(ep_repr.format("my.ep"), str(ep))
+        self.assertEqual(ep_repr.format("my.ep"), repr(ep))
 
     ###########################################################################
     # Private interface.
     ###########################################################################
 
-    def _create_extension_point(self, id, trait_type=List, desc=''):
+    def _create_extension_point(self, id, trait_type=List, desc=""):
         """ Create an extension point. """
 
         return ExtensionPoint(id=id, trait_type=trait_type, desc=desc)
