@@ -1,20 +1,25 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ Tests for the events fired when extension points are changed. """
 
-
-# Enthought library imports.
-from traits.testing.unittest_tools import unittest
+# Standard library imports.
+import unittest
 
 # Local imports.
+from envisage.api import ExtensionPointChangedEvent
 from envisage.tests.test_application import (
-    PluginA, PluginB, PluginC, TestApplication, listener
+    PluginA,
+    PluginB,
+    PluginC,
+    TestApplication,
+    listener,
 )
 
 
@@ -42,10 +47,28 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         with self.assertRaises(SystemError):
             setattr(a, "x", [1, 2, 3])
 
+    def test_mutate_extension_point_no_events(self):
+        """ Mutation will not emit change event for name_items """
+
+        a = PluginA()
+        a.on_trait_change(listener, "x_items")
+        b = PluginB()
+        c = PluginC()
+
+        application = TestApplication(plugins=[a, b, c])
+        application.start()
+
+        # when
+        a.x.append(42)
+
+        # then
+        self.assertIsNone(listener.obj)
+
     def test_append(self):
         """ append """
 
-        a = PluginA(); a.on_trait_change(listener, 'x_items')
+        a = PluginA()
+        a.on_trait_change(listener, "x_items")
         b = PluginB()
         c = PluginC()
 
@@ -61,7 +84,7 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         b.x.append(4)
 
         # Make sure we pick up the new contribution via the application.
-        extensions = application.get_extensions('a.x')
+        extensions = application.get_extensions("a.x")
         extensions.sort()
 
         self.assertEqual(7, len(extensions))
@@ -77,7 +100,7 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         # Make sure we got a trait event telling us that the contributions
         # to the extension point have been changed.
         self.assertEqual(a, listener.obj)
-        self.assertEqual('x_items', listener.trait_name)
+        self.assertEqual("x_items", listener.trait_name)
         self.assertEqual([4], listener.new.added)
         self.assertEqual([], listener.new.removed)
         self.assertEqual(3, listener.new.index)
@@ -85,7 +108,8 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
     def test_remove(self):
         """ remove """
 
-        a = PluginA(); a.on_trait_change(listener, 'x_items')
+        a = PluginA()
+        a.on_trait_change(listener, "x_items")
         b = PluginB()
         c = PluginC()
 
@@ -101,7 +125,7 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         b.x.remove(3)
 
         # Make sure we pick up the correct contributions via the application.
-        extensions = application.get_extensions('a.x')
+        extensions = application.get_extensions("a.x")
         extensions.sort()
 
         self.assertEqual(5, len(extensions))
@@ -117,7 +141,7 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         # Make sure we got a trait event telling us that the contributions
         # to the extension point have been changed.
         self.assertEqual(a, listener.obj)
-        self.assertEqual('x_items', listener.trait_name)
+        self.assertEqual("x_items", listener.trait_name)
         self.assertEqual([], listener.new.added)
         self.assertEqual([3], listener.new.removed)
         self.assertEqual(2, listener.new.index)
@@ -125,7 +149,8 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
     def test_assign_empty_list(self):
         """ assign empty list """
 
-        a = PluginA(); a.on_trait_change(listener, 'x_items')
+        a = PluginA()
+        a.on_trait_change(listener, "x_items")
         b = PluginB()
         c = PluginC()
 
@@ -141,7 +166,7 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         b.x = []
 
         # Make sure we pick up the correct contribution via the application.
-        extensions = application.get_extensions('a.x')
+        extensions = application.get_extensions("a.x")
         extensions.sort()
 
         self.assertEqual(3, len(extensions))
@@ -157,7 +182,7 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         # Make sure we got a trait event telling us that the contributions
         # to the extension point have been changed.
         self.assertEqual(a, listener.obj)
-        self.assertEqual('x_items', listener.trait_name)
+        self.assertEqual("x_items", listener.trait_name)
         self.assertEqual([], listener.new.added)
         self.assertEqual([1, 2, 3], listener.new.removed)
         self.assertEqual(0, listener.new.index.start)
@@ -166,7 +191,8 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
     def test_assign_empty_list_no_event(self):
         """ assign empty list no event """
 
-        a = PluginA(); a.on_trait_change(listener, 'x_items')
+        a = PluginA()
+        a.on_trait_change(listener, "x_items")
         b = PluginB()
         c = PluginC()
 
@@ -177,7 +203,7 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         b.x = []
 
         # Make sure we pick up the correct contribution via the application.
-        extensions = application.get_extensions('a.x')
+        extensions = application.get_extensions("a.x")
         extensions.sort()
 
         self.assertEqual(3, len(extensions))
@@ -197,7 +223,8 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
     def test_assign_non_empty_list(self):
         """ assign non-empty list """
 
-        a = PluginA(); a.on_trait_change(listener, 'x_items')
+        a = PluginA()
+        a.on_trait_change(listener, "x_items")
         b = PluginB()
         c = PluginC()
 
@@ -209,11 +236,14 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         # won't fire a changed event.
         self.assertEqual([1, 2, 3, 98, 99, 100], a.x)
 
+        # Keep the old values for later slicing check
+        source_values = list(a.x)
+
         # Assign a non-empty list to one of the plugin's contributions.
         b.x = [2, 4, 6, 8]
 
         # Make sure we pick up the new contribution via the application.
-        extensions = application.get_extensions('a.x')
+        extensions = application.get_extensions("a.x")
         extensions.sort()
 
         self.assertEqual(7, len(extensions))
@@ -229,16 +259,28 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         # Make sure we got a trait event telling us that the contributions
         # to the extension point have been changed.
         self.assertEqual(a, listener.obj)
-        self.assertEqual('x_items', listener.trait_name)
+        self.assertEqual("x_items", listener.trait_name)
         self.assertEqual([2, 4, 6, 8], listener.new.added)
         self.assertEqual([1, 2, 3], listener.new.removed)
+
+        # The removed entry should match what the old values say
+        self.assertEqual(
+            listener.new.removed, source_values[listener.new.index]
+        )
+
+        # If we use the index and apply the changes to the old list, we should
+        # recover the new list
+        source_values[listener.new.index] = listener.new.added
+        self.assertEqual(source_values, application.get_extensions("a.x"))
+
         self.assertEqual(0, listener.new.index.start)
-        self.assertEqual(4, listener.new.index.stop)
+        self.assertEqual(3, listener.new.index.stop)
 
     def test_add_plugin(self):
         """ add plugin """
 
-        a = PluginA(); a.on_trait_change(listener, 'x_items')
+        a = PluginA()
+        a.on_trait_change(listener, "x_items")
         b = PluginB()
         c = PluginC()
 
@@ -247,7 +289,7 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         application.start()
 
         # Make sure we can get the contributions via the application.
-        extensions = application.get_extensions('a.x')
+        extensions = application.get_extensions("a.x")
         extensions.sort()
 
         self.assertEqual(3, len(extensions))
@@ -264,7 +306,7 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         application.add_plugin(c)
 
         # Make sure we can get the contributions via the application.
-        extensions = application.get_extensions('a.x')
+        extensions = application.get_extensions("a.x")
         extensions.sort()
 
         self.assertEqual(6, len(extensions))
@@ -280,7 +322,7 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         # Make sure we got a trait event telling us that the contributions
         # to the extension point have been changed.
         self.assertEqual(a, listener.obj)
-        self.assertEqual('x_items', listener.trait_name)
+        self.assertEqual("x_items", listener.trait_name)
         self.assertEqual([98, 99, 100], listener.new.added)
         self.assertEqual([], listener.new.removed)
         self.assertEqual(3, listener.new.index)
@@ -288,7 +330,8 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
     def test_remove_plugin(self):
         """ remove plugin """
 
-        a = PluginA(); a.on_trait_change(listener, 'x_items')
+        a = PluginA()
+        a.on_trait_change(listener, "x_items")
         b = PluginB()
         c = PluginC()
 
@@ -296,7 +339,7 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         application.start()
 
         # Make sure we can get the contributions via the application.
-        extensions = application.get_extensions('a.x')
+        extensions = application.get_extensions("a.x")
         extensions.sort()
 
         self.assertEqual(6, len(extensions))
@@ -313,7 +356,7 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         application.remove_plugin(b)
 
         # Make sure we can get the contributions via the application.
-        extensions = application.get_extensions('a.x')
+        extensions = application.get_extensions("a.x")
         extensions.sort()
 
         self.assertEqual(3, len(extensions))
@@ -329,7 +372,16 @@ class ExtensionPointChangedTestCase(unittest.TestCase):
         # Make sure we got a trait event telling us that the contributions
         # to the extension point have been changed.
         self.assertEqual(a, listener.obj)
-        self.assertEqual('x_items', listener.trait_name)
+        self.assertEqual("x_items", listener.trait_name)
         self.assertEqual([], listener.new.added)
         self.assertEqual([1, 2, 3], listener.new.removed)
         self.assertEqual(0, listener.new.index)
+
+    def test_extension_point_change_event_str_representation(self):
+        """ test string representation of the ExtensionPointChangedEvent class
+        """
+        desired_repr = ("ExtensionPointChangedEvent(extension_point_id={}, "
+                        "index=0, removed=[], added=[])")
+        ext_pt_changed_evt = ExtensionPointChangedEvent(extension_point_id=1)
+        self.assertEqual(desired_repr.format(1), str(ext_pt_changed_evt))
+        self.assertEqual(desired_repr.format(1), repr(ext_pt_changed_evt))
