@@ -1,15 +1,15 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ Tests for the provider extension registry. """
 
-
-# Standard imports
+# Standard library imports.
 import unittest
 
 # Enthought library imports.
@@ -18,32 +18,20 @@ from envisage.api import ProviderExtensionRegistry
 from traits.api import Int, List
 
 # Local imports.
-from .test_extension_registry import ExtensionRegistryTestCase
+from envisage.tests.test_extension_registry_mixin import (
+    ExtensionRegistryTestMixin
+)
 
 
-class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
+class ProviderExtensionRegistryTestCase(
+        ExtensionRegistryTestMixin, unittest.TestCase):
     """ Tests for the provider extension registry. """
 
-    ###########################################################################
-    # 'TestCase' interface.
-    ###########################################################################
-
     def setUp(self):
         """ Prepares the test fixture before each test method is called. """
 
         self.registry = ProviderExtensionRegistry()
 
-        return
-
-    def tearDown(self):
-        """ Called immediately after each test method has been called. """
-
-        return
-
-    ###########################################################################
-    # Tests.
-    ###########################################################################
-
     def test_providers(self):
         """ providers """
 
@@ -56,14 +44,14 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             def get_extension_points(self):
                 """ Return the extension points offered by the provider. """
 
-                return [ExtensionPoint(List, 'x')]
+                return [ExtensionPoint(List, "x")]
 
             def get_extensions(self, extension_point):
                 """ Return the provider's contributions to an extension point.
 
                 """
 
-                if extension_point == 'x':
+                if extension_point == "x":
                     extensions = [42, 43]
 
                 else:
@@ -79,7 +67,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
 
                 """
 
-                if extension_point == 'x':
+                if extension_point == "x":
                     extensions = [44, 45, 46]
 
                 else:
@@ -90,23 +78,20 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         class ProviderC(ExtensionProvider):
             """ An empty provider! """
 
-
         # Add the providers to the registry.
         registry.add_provider(ProviderA())
         registry.add_provider(ProviderB())
         registry.add_provider(ProviderC())
 
         # The provider's extensions should now be in the registry.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(5, len(extensions))
         self.assertEqual(list(range(42, 47)), extensions)
 
         # Make sure there's one and only one extension point.
         extension_points = registry.get_extension_points()
         self.assertEqual(1, len(extension_points))
-        self.assertEqual('x', extension_points[0].id)
-
-        return
+        self.assertEqual("x", extension_points[0].id)
 
     def test_provider_extensions_changed(self):
         """ provider extensions changed """
@@ -122,14 +107,14 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             def get_extension_points(self):
                 """ Return the extension points offered by the provider. """
 
-                return [ExtensionPoint(List, 'my.ep')]
+                return [ExtensionPoint(List, "my.ep")]
 
             def get_extensions(self, extension_point_id):
                 """ Return the provider's contributions to an extension point.
 
                 """
 
-                if extension_point_id == 'my.ep':
+                if extension_point_id == "my.ep":
                     return self.x
 
                 else:
@@ -141,21 +126,16 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
                 """ Static trait change handler. """
 
                 self._fire_extension_point_changed(
-                    'my.ep', new, old, slice(0, len(old))
+                    "my.ep", new, old, slice(0, len(old))
                 )
 
-                return
-
             def _x_items_changed(self, event):
                 """ Static trait change handler. """
 
                 self._fire_extension_point_changed(
-                    'my.ep', event.added, event.removed, event.index
+                    "my.ep", event.added, event.removed, event.index
                 )
 
-                return
-
-
         class ProviderB(ExtensionProvider):
             """ An extension provider. """
 
@@ -166,7 +146,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
 
                 """
 
-                if extension_point_id == 'my.ep':
+                if extension_point_id == "my.ep":
                     return self.x
 
                 else:
@@ -178,20 +158,16 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
                 """ Static trait change handler. """
 
                 self._fire_extension_point_changed(
-                    'my.ep', new, old, slice(0, len(old))
+                    "my.ep", new, old, slice(0, len(old))
                 )
 
-                return
-
             def _x_items_changed(self, event):
                 """ Static trait change handler. """
 
                 self._fire_extension_point_changed(
-                    'my.ep', event.added, event.removed, event.index
+                    "my.ep", event.added, event.removed, event.index
                 )
 
-                return
-
         # Add the providers to the registry.
         a = ProviderA(x=[42])
         b = ProviderB(x=[99, 100])
@@ -199,7 +175,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         registry.add_provider(b)
 
         # The provider's extensions should now be in the registry.
-        extensions = registry.get_extensions('my.ep')
+        extensions = registry.get_extensions("my.ep")
         self.assertEqual(3, len(extensions))
         self.assertEqual([42, 99, 100], extensions)
 
@@ -213,21 +189,19 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             listener.removed = event.removed
             listener.index = event.index
 
-            return
-
-        registry.add_extension_point_listener(listener, 'my.ep')
+        registry.add_extension_point_listener(listener, "my.ep")
 
         # Add a new extension via the provider.
         a.x.append(43)
 
         # Make sure the listener got called.
-        self.assertEqual('my.ep', listener.extension_point)
+        self.assertEqual("my.ep", listener.extension_point)
         self.assertEqual([43], listener.added)
         self.assertEqual([], listener.removed)
         self.assertEqual(1, listener.index)
 
         # Now we should get the new extension.
-        extensions = registry.get_extensions('my.ep')
+        extensions = registry.get_extensions("my.ep")
         self.assertEqual(4, len(extensions))
         self.assertEqual([42, 43, 99, 100], extensions)
 
@@ -235,13 +209,13 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         b.x.insert(0, 98)
 
         # Make sure the listener got called.
-        self.assertEqual('my.ep', listener.extension_point)
+        self.assertEqual("my.ep", listener.extension_point)
         self.assertEqual([98], listener.added)
         self.assertEqual([], listener.removed)
         self.assertEqual(2, listener.index)
 
         # Now we should get the new extension.
-        extensions = registry.get_extensions('my.ep')
+        extensions = registry.get_extensions("my.ep")
         self.assertEqual(5, len(extensions))
         self.assertEqual([42, 43, 98, 99, 100], extensions)
 
@@ -249,19 +223,17 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         b.x = [1, 2]
 
         # Make sure the listener got called.
-        self.assertEqual('my.ep', listener.extension_point)
+        self.assertEqual("my.ep", listener.extension_point)
         self.assertEqual([1, 2], listener.added)
         self.assertEqual([98, 99, 100], listener.removed)
         self.assertEqual(2, listener.index.start)
         self.assertEqual(5, listener.index.stop)
 
         # Now we should get the new extension.
-        extensions = registry.get_extensions('my.ep')
+        extensions = registry.get_extensions("my.ep")
         self.assertEqual(4, len(extensions))
         self.assertEqual([42, 43, 1, 2], extensions)
 
-        return
-
     def test_add_provider(self):
         """ add provider """
 
@@ -274,14 +246,14 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             def get_extension_points(self):
                 """ Return the extension points offered by the provider. """
 
-                return [ExtensionPoint(List, 'x')]
+                return [ExtensionPoint(List, "x")]
 
             def get_extensions(self, extension_point):
                 """ Return the provider's contributions to an extension point.
 
                 """
 
-                if extension_point == 'x':
+                if extension_point == "x":
                     return [42]
 
                 else:
@@ -293,18 +265,16 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
                 """ Static trait change handler. """
 
                 self._fire_extension_point_changed(
-                    'x', event.added, event.removed, event.index
+                    "x", event.added, event.removed, event.index
                 )
 
-                return
-
         # Add the provider to the registry.
         registry.add_provider(ProviderA())
 
         # The provider's extensions should now be in the registry.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(1, len(extensions))
-        self.assert_(42 in extensions)
+        self.assertTrue(42 in extensions)
 
         # Add an extension listener to the registry.
         def listener(registry, event):
@@ -316,9 +286,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             listener.removed = event.removed
             listener.index = event.index
 
-            return
-
-        registry.add_extension_point_listener(listener, 'x')
+        registry.add_extension_point_listener(listener, "x")
 
         # Add a new provider.
         class ProviderB(ExtensionProvider):
@@ -329,7 +297,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
 
                 """
 
-                if extension_point == 'x':
+                if extension_point == "x":
                     extensions = [43, 44]
 
                 else:
@@ -340,18 +308,16 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         registry.add_provider(ProviderB())
 
         # Make sure the listener got called.
-        self.assertEqual('x', listener.extension_point)
+        self.assertEqual("x", listener.extension_point)
         self.assertEqual([43, 44], listener.added)
         self.assertEqual([], listener.removed)
 
         # Now we should get the new extensions.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(3, len(extensions))
-        self.assert_(42 in extensions)
-        self.assert_(43 in extensions)
-        self.assert_(44 in extensions)
-
-        return
+        self.assertTrue(42 in extensions)
+        self.assertTrue(43 in extensions)
+        self.assertTrue(44 in extensions)
 
     def test_get_providers(self):
         """ get providers """
@@ -375,8 +341,6 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         # Make sure we can get them.
         self.assertEqual([a, b], registry.get_providers())
 
-        return
-
     def test_remove_provider(self):
         """ remove provider """
 
@@ -389,14 +353,14 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             def get_extension_points(self):
                 """ Return the extension points offered by the provider. """
 
-                return [ExtensionPoint(List, 'x'), ExtensionPoint(List, 'y')]
+                return [ExtensionPoint(List, "x"), ExtensionPoint(List, "y")]
 
             def get_extensions(self, extension_point):
                 """ Return the provider's contributions to an extension point.
 
                 """
 
-                if extension_point == 'x':
+                if extension_point == "x":
                     return [42]
 
                 else:
@@ -408,11 +372,9 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
                 """ Static trait change handler. """
 
                 self._fire_extension_point_changed(
-                    'x', event.added, event.removed, event.index
+                    "x", event.added, event.removed, event.index
                 )
 
-                return
-
         class ProviderB(ExtensionProvider):
             """ An extension provider. """
 
@@ -421,7 +383,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
 
                 """
 
-                if extension_point == 'x':
+                if extension_point == "x":
                     extensions = [43, 44]
 
                 else:
@@ -436,11 +398,11 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         registry.add_provider(b)
 
         # The provider's extensions should now be in the registry.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(3, len(extensions))
-        self.assert_(42 in extensions)
-        self.assert_(43 in extensions)
-        self.assert_(44 in extensions)
+        self.assertTrue(42 in extensions)
+        self.assertTrue(43 in extensions)
+        self.assertTrue(44 in extensions)
 
         # Add an extension listener to the registry.
         def listener(registry, event):
@@ -451,40 +413,36 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             listener.added = event.added
             listener.removed = event.removed
 
-            return
-
-        registry.add_extension_point_listener(listener, 'x')
+        registry.add_extension_point_listener(listener, "x")
 
         # Remove one of the providers.
         registry.remove_provider(b)
 
         # Make sure the listener got called.
-        self.assertEqual('x', listener.extension_point)
+        self.assertEqual("x", listener.extension_point)
         self.assertEqual([], listener.added)
         self.assertEqual([43, 44], listener.removed)
 
         # Make sure we don't get the removed extensions.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(1, len(extensions))
-        self.assert_(42 in extensions)
+        self.assertTrue(42 in extensions)
 
         # Now remove the provider that declared the extension point.
         registry.remove_provider(a)
 
         # Make sure the extension point is gone.
-        self.assertEqual(None, registry.get_extension_point('x'))
+        self.assertEqual(None, registry.get_extension_point("x"))
 
         # Make sure we don't get the removed extensions.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(0, len(extensions))
 
         # Make sure the listener got called.
-        self.assertEqual('x', listener.extension_point)
+        self.assertEqual("x", listener.extension_point)
         self.assertEqual([], listener.added)
         self.assertEqual([42], listener.removed)
 
-        return
-
     def test_remove_provider_with_no_contributions(self):
         """ remove provider with no contributions """
 
@@ -497,7 +455,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             def get_extension_points(self):
                 """ Return the extension points offered by the provider. """
 
-                return [ExtensionPoint(List, 'x'), ExtensionPoint(List, 'y')]
+                return [ExtensionPoint(List, "x"), ExtensionPoint(List, "y")]
 
             def get_extensions(self, extension_point):
                 """ Return the provider's contributions to an extension point.
@@ -511,7 +469,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         registry.add_provider(a)
 
         # The provider's extensions should now be in the registry.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(0, len(extensions))
 
         # Add an extension listener to the registry.
@@ -523,25 +481,21 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             listener.added = event.added
             listener.removed = event.removed
 
-            return
-
-        registry.add_extension_point_listener(listener, 'x')
+        registry.add_extension_point_listener(listener, "x")
 
         # Remove the provider that declared the extension point.
         registry.remove_provider(a)
 
         # Make sure the extension point is gone.
-        self.assertEqual(None, registry.get_extension_point('x'))
+        self.assertEqual(None, registry.get_extension_point("x"))
 
         # Make sure we don't get the removed extensions.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(0, len(extensions))
 
         # Make sure the listener did not get called  (since the provider did
         # not make any contributions anyway!).
-        self.assertEqual(None, getattr(listener, 'registry', None))
-
-        return
+        self.assertEqual(None, getattr(listener, "registry", None))
 
     def test_remove_non_existent_provider(self):
         """ remove provider """
@@ -557,26 +511,20 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         a = ProviderA()
 
         # Remove one of the providers.
-        self.failUnlessRaises(ValueError, registry.remove_provider, a)
+        with self.assertRaises(ValueError):
+            registry.remove_provider(a)
 
-        return
-
-    # Overriden to test differing behavior between the provider registry and
-    # the base class.
     def test_set_extensions(self):
         """ set extensions """
 
         registry = self.registry
 
         # Add an extension *point*.
-        registry.add_extension_point(self._create_extension_point('my.ep'))
+        registry.add_extension_point(self.create_extension_point("my.ep"))
 
         # Set some extensions.
-        self.failUnlessRaises(
-            SystemError, registry.set_extensions, 'my.ep', [1, 2, 3]
-        )
-
-        return
+        with self.assertRaises(SystemError):
+            registry.set_extensions("my.ep", [1, 2, 3])
 
     def test_remove_non_empty_extension_point(self):
         """ remove non-empty extension point """
@@ -590,14 +538,14 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             def get_extension_points(self):
                 """ Return the extension points offered by the provider. """
 
-                return [ExtensionPoint(List, 'x')]
+                return [ExtensionPoint(List, "x")]
 
             def get_extensions(self, extension_point):
                 """ Return the provider's contributions to an extension point.
 
                 """
 
-                if extension_point == 'x':
+                if extension_point == "x":
                     extensions = [42, 43]
 
                 else:
@@ -609,30 +557,21 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         registry.add_provider(ProviderA())
 
         # The provider's extensions should now be in the registry.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(2, len(extensions))
         self.assertEqual(list(range(42, 44)), extensions)
 
         # Make sure there's one and only one extension point.
         extension_points = registry.get_extension_points()
         self.assertEqual(1, len(extension_points))
-        self.assertEqual('x', extension_points[0].id)
+        self.assertEqual("x", extension_points[0].id)
 
         # Remove the extension point.
-        registry.remove_extension_point('x')
+        registry.remove_extension_point("x")
 
         # Make sure there are no extension points.
         extension_points = registry.get_extension_points()
         self.assertEqual(0, len(extension_points))
 
         # And that the extensions are gone too.
-        self.assertEqual([], registry.get_extensions('x'))
-
-        return
-
-
-# Entry point for stand-alone testing.
-if __name__ == '__main__':
-    unittest.main()
-
-#### EOF ######################################################################
+        self.assertEqual([], registry.get_extensions("x"))
