@@ -1,24 +1,26 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ Tests for the 'Service' trait type. """
 
+# Standard library imports.
+import unittest
 
 # Enthought library imports.
 from envisage.api import Application, Plugin, Service
 from traits.api import HasTraits, Instance
-from traits.testing.unittest_tools import unittest
 
 
 class TestApplication(Application):
     """ The type of application used in the tests. """
 
-    id = 'test'
+    id = "test"
 
 
 class ServiceTestCase(unittest.TestCase):
@@ -31,11 +33,11 @@ class ServiceTestCase(unittest.TestCase):
             pass
 
         class PluginA(Plugin):
-            id = 'A'
+            id = "A"
             foo = Instance(Foo, (), service=True)
 
         class PluginB(Plugin):
-            id = 'B'
+            id = "B"
             foo = Service(Foo)
 
         a = PluginA()
@@ -71,3 +73,14 @@ class ServiceTestCase(unittest.TestCase):
         b = Bar()
         with self.assertRaises(ValueError):
             getattr(b, "foo")
+
+    def test_service_str_representation(self):
+        """ test the string representation of the service """
+
+        class Foo(HasTraits):
+            pass
+
+        service_repr = "Service(protocol={!r})"
+        service = Service(Foo)
+        self.assertEqual(service_repr.format(Foo), str(service))
+        self.assertEqual(service_repr.format(Foo), repr(service))
