@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ The *definition* of an action in a tool bar or menu. """
 
@@ -34,8 +35,6 @@ class Action(Location):
     def __str__(self):
         """ Return the 'informal' string representation of the object. """
 
-        return 'Action(%s)' % self.name
+        return "Action(%s)" % self.name
 
     __repr__ = __str__
-
-#### EOF ######################################################################
