@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ An action set is a collection of menus, groups, and actions. """
 
@@ -98,8 +99,8 @@ class ActionSet(HasTraits):
     def _id_default(self):
         """ Trait initializer. """
 
-        id = '%s.%s' % (type(self).__module__, type(self).__name__)
-        logger.warning('action set %s has no Id - using <%s>' % (self, id))
+        id = "%s.%s" % (type(self).__module__, type(self).__name__)
+        logger.warning("action set %s has no Id - using <%s>" % (self, id))
 
         return id
 
@@ -107,8 +108,6 @@ class ActionSet(HasTraits):
         """ Trait initializer. """
 
         name = camel_case_to_words(type(self).__name__)
-        logger.warning('action set %s has no name - using <%s>' % (self, name))
+        logger.warning("action set %s has no name - using <%s>" % (self, name))
 
         return name
-
-#### EOF ######################################################################
