@@ -1,25 +1,33 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 # Standard library imports.
 import logging
+import pickle
 import os.path
 
 # Enthought library imports.
 from envisage.api import Application, ExtensionPoint
 from traits.api import (
-    Bool, Callable, Directory, Event, HasStrictTraits,
-    Instance, Int, List, Unicode, Vetoable)
+    Bool,
+    Callable,
+    Directory,
+    Event,
+    HasStrictTraits,
+    Instance,
+    Int,
+    List,
+    Str,
+    Vetoable,
+)
 from traits.etsconfig.api import ETSConfig
 
-# Local imports
-from envisage._compat import pickle, STRING_BASE_CLASS
-
 
 # Logging.
 logger = logging.getLogger(__name__)
@@ -36,99 +44,105 @@ class TasksApplication(Application):
 
     """
 
-    # Extension point IDs.
-    TASK_FACTORIES = 'envisage.ui.tasks.tasks'
-    TASK_EXTENSIONS = 'envisage.ui.tasks.task_extensions'
+    #: Extension point ID for task factories
+    TASK_FACTORIES = "envisage.ui.tasks.tasks"
 
-    # Pickle protocol to use for persisting layout information. Subclasses may
-    # want to increase this, depending on their compatibility needs. Protocol
-    # version 2 is safe for Python >= 2.3. Protocol version 4 is safe for
-    # Python >= 3.4.
+    #: Extension point ID for task extensions
+    TASK_EXTENSIONS = "envisage.ui.tasks.task_extensions"
+
+    #: Pickle protocol to use for persisting layout information. Subclasses may
+    #: want to increase this, depending on their compatibility needs. Protocol
+    #: version 2 is safe for Python >= 2.3. Protocol version 4 is safe for
+    #: Python >= 3.4.
     layout_save_protocol = Int(2)
 
     #### 'TasksApplication' interface #########################################
 
-    # The active task window (the last one to get focus).
-    active_window = Instance('envisage.ui.tasks.task_window.TaskWindow')
+    #: The active task window (the last one to get focus).
+    active_window = Instance("envisage.ui.tasks.task_window.TaskWindow")
 
-    # The Pyface GUI for the application.
-    gui = Instance('pyface.gui.GUI')
+    #: The Pyface GUI for the application.
+    gui = Instance("pyface.i_gui.IGUI")
 
-    # Icon for the whole application. Will be used to override all taskWindows
-    # icons to have the same.
-    icon = Instance('pyface.image_resource.ImageResource', allow_none=True)
+    #: Icon for the whole application. Will be used to override all taskWindows
+    #: icons to have the same.
+    icon = Instance("pyface.image_resource.ImageResource", allow_none=True)
 
-    # The name of the application (also used on window title bars).
-    name = Unicode
+    #: The name of the application (also used on window title bars).
+    name = Str
 
-    # The splash screen for the application. By default, there is no splash
-    # screen.
-    splash_screen = Instance('pyface.splash_screen.SplashScreen')
+    #: The splash screen for the application. By default, there is no splash
+    #: screen.
+    splash_screen = Instance("pyface.splash_screen.SplashScreen")
 
-    # The directory on the local file system used to persist window layout
-    # information.
+    #: The directory on the local file system used to persist window layout
+    #: information.
     state_location = Directory
 
-    # The filename that the application uses to persist window layout
-    # information.
-    state_filename = Unicode(DEFAULT_STATE_FILENAME)
+    #: The filename that the application uses to persist window layout
+    #: information.
+    state_filename = Str(DEFAULT_STATE_FILENAME)
 
-    # Contributed task factories. This attribute is primarily for run-time
-    # inspection; to instantiate a task, use the 'create_task' method.
+    #: Contributed task factories. This attribute is primarily for run-time
+    #: inspection; to instantiate a task, use the 'create_task' method.
     task_factories = ExtensionPoint(id=TASK_FACTORIES)
 
-    # Contributed task extensions.
+    #: Contributed task extensions.
     task_extensions = ExtensionPoint(id=TASK_EXTENSIONS)
 
-    # The list of task windows created by the application.
-    windows = List(Instance('envisage.ui.tasks.task_window.TaskWindow'))
+    #: The list of task windows created by the application.
+    windows = List(Instance("envisage.ui.tasks.task_window.TaskWindow"))
 
-    # The factory for creating task windows.
+    #: The factory for creating task windows.
     window_factory = Callable
 
     #### Application layout ###################################################
 
-    # The default layout for the application. If not specified, a single window
-    # will be created with the first available task factory.
+    #: The default layout for the application. If not specified, a single
+    #: window will be created with the first available task factory.
     default_layout = List(
-        Instance('pyface.tasks.task_window_layout.TaskWindowLayout'))
+        Instance("pyface.tasks.task_window_layout.TaskWindowLayout")
+    )
 
-    # Whether to always apply the default *application level* layout when the
-    # application is started. Even if this is True, the layout state of
-    # individual tasks will be restored.
+    #: Whether to always apply the default *application level* layout when the
+    #: application is started. Even if this is True, the layout state of
+    #: individual tasks will be restored.
     always_use_default_layout = Bool(False)
 
     #### Application lifecycle events #########################################
 
-    # Fired after the initial windows have been created and the GUI event loop
-    # has been started.
+    #: Fired after the initial windows have been created and the GUI event loop
+    #: has been started.
     application_initialized = Event
 
-    # Fired immediately before the extant windows are destroyed and the GUI
-    # event loop is terminated.
+    #: Fired immediately before the extant windows are destroyed and the GUI
+    #: event loop is terminated.
     application_exiting = Event
 
-    # Fired when a task window has been created.
+    #: Fired when a task window has been created.
     window_created = Event(
-        Instance('envisage.ui.tasks.task_window_event.TaskWindowEvent'))
+        Instance("envisage.ui.tasks.task_window_event.TaskWindowEvent")
+    )
 
-    # Fired when a task window is opening.
+    #: Fired when a task window is opening.
     window_opening = Event(
-        Instance(
-            'envisage.ui.tasks.task_window_event.VetoableTaskWindowEvent'))
+        Instance("envisage.ui.tasks.task_window_event.VetoableTaskWindowEvent")
+    )
 
-    # Fired when a task window has been opened.
+    #: Fired when a task window has been opened.
     window_opened = Event(
-        Instance('envisage.ui.tasks.task_window_event.TaskWindowEvent'))
+        Instance("envisage.ui.tasks.task_window_event.TaskWindowEvent")
+    )
 
-    # Fired when a task window is closing.
+    #: Fired when a task window is closing.
     window_closing = Event(
-        Instance(
-            'envisage.ui.tasks.task_window_event.VetoableTaskWindowEvent'))
+        Instance("envisage.ui.tasks.task_window_event.VetoableTaskWindowEvent")
+    )
 
-    # Fired when a task window has been closed.
+    #: Fired when a task window has been closed.
     window_closed = Event(
-        Instance('envisage.ui.tasks.task_window_event.TaskWindowEvent'))
+        Instance("envisage.ui.tasks.task_window_event.TaskWindowEvent")
+    )
 
     #### Protected interface ##################################################
 
@@ -138,7 +152,8 @@ class TasksApplication(Application):
 
     # Application state.
     _state = Instance(
-        'envisage.ui.tasks.tasks_application.TasksApplicationState')
+        "envisage.ui.tasks.tasks_application.TasksApplicationState"
+    )
 
     ###########################################################################
     # 'IApplication' interface.
@@ -163,7 +178,7 @@ class TasksApplication(Application):
             self._create_windows()
 
             # Start the GUI event loop.
-            gui.set_trait_later(self, 'application_initialized', self)
+            gui.set_trait_later(self, "application_initialized", self)
             gui.start_event_loop()
 
         return started
@@ -186,8 +201,11 @@ class TasksApplication(Application):
             return None
 
         # Create the task using suitable task extensions.
-        extensions = [ext for ext in self.task_extensions
-                      if ext.task_id == id or not ext.task_id]
+        extensions = [
+            ext
+            for ext in self.task_extensions
+            if ext.task_id == id or not ext.task_id
+        ]
         task = factory.create_with_extensions(extensions)
         task.id = factory.id
         return task
@@ -224,11 +242,11 @@ class TasksApplication(Application):
         window = self.window_factory(application=self, **traits)
 
         # Listen for the window events.
-        window.on_trait_change(self._on_window_activated, 'activated')
-        window.on_trait_change(self._on_window_opening, 'opening')
-        window.on_trait_change(self._on_window_opened, 'opened')
-        window.on_trait_change(self._on_window_closing, 'closing')
-        window.on_trait_change(self._on_window_closed, 'closed')
+        window.on_trait_change(self._on_window_activated, "activated")
+        window.on_trait_change(self._on_window_opening, "opening")
+        window.on_trait_change(self._on_window_opened, "opened")
+        window.on_trait_change(self._on_window_closing, "closing")
+        window.on_trait_change(self._on_window_closed, "closed")
 
         # Event notification.
         self.window_created = TaskWindowEvent(window=window)
@@ -241,7 +259,8 @@ class TasksApplication(Application):
                     window.add_task(task)
                 else:
                     logger.error(
-                        'Missing factory for task with ID %r', task_id)
+                        "Missing factory for task with ID %r", task_id
+                    )
 
             # Apply a suitable layout.
             if restore:
@@ -306,8 +325,10 @@ class TasksApplication(Application):
         """
         # Build a list of TaskWindowLayouts.
         self._load_state()
-        if (self.always_use_default_layout or
-                not self._state.previous_window_layouts):
+        if (
+            self.always_use_default_layout
+            or not self._state.previous_window_layouts
+        ):
             window_layouts = self.default_layout
         else:
             # Choose the stored TaskWindowLayouts, but only if all the task IDs
@@ -316,9 +337,11 @@ class TasksApplication(Application):
             for layout in window_layouts:
                 for task_id in layout.get_tasks():
                     if not self._get_task_factory(task_id):
-                        logger.warning('Saved application layout references '
-                                       'non-existent task %r. Falling back to '
-                                       'default application layout.' % task_id)
+                        logger.warning(
+                            "Saved application layout references "
+                            "non-existent task %r. Falling back to "
+                            "default application layout." % task_id
+                        )
                         window_layouts = self.default_layout
                         break
                 else:
@@ -355,22 +378,24 @@ class TasksApplication(Application):
         filename = os.path.join(self.state_location, self.state_filename)
         if os.path.exists(filename):
             # Attempt to unpickle the saved application state.
-            logger.debug('Loading application state from %s', filename)
+            logger.debug("Loading application state from %s", filename)
             try:
-                with open(filename, 'rb') as f:
+                with open(filename, "rb") as f:
                     restored_state = pickle.load(f)
             except Exception:
                 # If anything goes wrong, log the error and continue.
-                logger.exception('Error while restoring application state')
+                logger.exception("Error while restoring application state")
             else:
                 if state.version == restored_state.version:
                     state = restored_state
-                    logger.debug('Application state successfully restored')
+                    logger.debug("Application state successfully restored")
                 else:
                     logger.warning(
-                        'Discarding outdated application state: '
-                        'expected version %s, got version %s',
-                        state.version, restored_state.version)
+                        "Discarding outdated application state: "
+                        "expected version %s, got version %s",
+                        state.version,
+                        restored_state.version,
+                    )
         else:
             logger.debug("No saved application state found at %s", filename)
 
@@ -392,7 +417,7 @@ class TasksApplication(Application):
         else:
             layout = layout.clone_traits()
             for i, item in enumerate(layout.items):
-                id = item if isinstance(item, STRING_BASE_CLASS) else item.id
+                id = item if isinstance(item, str) else item.id
                 match = self._state.get_task_layout(id)
                 if match:
                     layout.items[i] = match
@@ -408,24 +433,26 @@ class TasksApplication(Application):
 
         # Attempt to pickle the application state.
         filename = os.path.join(self.state_location, self.state_filename)
-        logger.debug('Saving application state to %s', filename)
+        logger.debug("Saving application state to %s", filename)
         try:
-            with open(filename, 'wb') as f:
+            with open(filename, "wb") as f:
                 pickle.dump(self._state, f, protocol=self.layout_save_protocol)
         except Exception:
             # If anything goes wrong, log the error and continue.
-            logger.exception('Error while saving application state')
+            logger.exception("Error while saving application state")
         else:
-            logger.debug('Application state successfully saved')
+            logger.debug("Application state successfully saved")
 
     #### Trait initializers ###################################################
 
     def _window_factory_default(self):
         from envisage.ui.tasks.task_window import TaskWindow
+
         return TaskWindow
 
     def _default_layout_default(self):
         from pyface.tasks.task_window_layout import TaskWindowLayout
+
         window_layout = TaskWindowLayout()
         if self.task_factories:
             window_layout.items = [self.task_factories[0].id]
@@ -433,15 +460,17 @@ class TasksApplication(Application):
 
     def _gui_default(self):
         from pyface.gui import GUI
+
         return GUI(splash_screen=self.splash_screen)
 
     def _state_location_default(self):
-        state_location = os.path.join(ETSConfig.application_home,
-                                      'tasks', ETSConfig.toolkit)
+        state_location = os.path.join(
+            ETSConfig.application_home, "tasks", ETSConfig.toolkit
+        )
         if not os.path.exists(state_location):
             os.makedirs(state_location)
 
-        logger.debug('Tasks state location is %s', state_location)
+        logger.debug("Tasks state location is %s", state_location)
 
         return state_location
 
@@ -452,15 +481,18 @@ class TasksApplication(Application):
 
     def _on_window_opening(self, window, trait_name, event):
         from .task_window_event import VetoableTaskWindowEvent
+
         # Event notification.
         self.window_opening = window_event = VetoableTaskWindowEvent(
-            window=window)
+            window=window
+        )
 
         if window_event.veto:
             event.veto = True
 
     def _on_window_opened(self, window, trait_name, event):
         from .task_window_event import TaskWindowEvent
+
         self.windows.append(window)
 
         # Event notification.
@@ -468,9 +500,11 @@ class TasksApplication(Application):
 
     def _on_window_closing(self, window, trait_name, event):
         from .task_window_event import VetoableTaskWindowEvent
+
         # Event notification.
         self.window_closing = window_event = VetoableTaskWindowEvent(
-            window=window)
+            window=window
+        )
 
         if window_event.veto:
             event.veto = True
@@ -486,6 +520,7 @@ class TasksApplication(Application):
 
     def _on_window_closed(self, window, trait_name, event):
         from .task_window_event import TaskWindowEvent
+
         self.windows.remove(window)
 
         # Event notification.
@@ -504,12 +539,14 @@ class TasksApplicationState(HasStrictTraits):
     # TaskWindowLayouts for the windows extant at application
     # exit. Only used if 'always_use_default_layout' is disabled.
     previous_window_layouts = List(
-        Instance('pyface.tasks.task_window_layout.TaskWindowLayout'))
+        Instance("pyface.tasks.task_window_layout.TaskWindowLayout")
+    )
 
     # A list of TaskWindowLayouts accumulated throughout the application's
     # lifecycle.
     window_layouts = List(
-        Instance('pyface.tasks.task_window_layout.TaskWindowLayout'))
+        Instance("pyface.tasks.task_window_layout.TaskWindowLayout")
+    )
 
     # The "version" for the state data. This should be incremented whenever a
     # backwards incompatible change is made to this class or any of the layout
@@ -536,6 +573,9 @@ class TasksApplicationState(HasStrictTraits):
     def push_window_layout(self, window_layout):
         """ Merge a TaskWindowLayout into the accumulated list.
         """
-        self.window_layouts = [layout for layout in self.window_layouts
-                               if not layout.is_equivalent_to(window_layout)]
+        self.window_layouts = [
+            layout
+            for layout in self.window_layouts
+            if not layout.is_equivalent_to(window_layout)
+        ]
         self.window_layouts.insert(0, window_layout)
