@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2020 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ An action that exits the workbench. """
 
@@ -20,16 +21,16 @@ class ExitAction(Action):
     #### 'Action' interface ###################################################
 
     # A longer description of the action.
-    description = 'Exit the application'
+    description = "Exit the application"
 
     # The action's image (displayed on tool bar tools etc).
-    image = ImageResource('exit')
+    image = ImageResource("exit")
 
     # The action's name (displayed on menus/tool bar tools etc).
-    name = 'Exit'
+    name = "Exit"
 
     # A short description of the action used for tooltip text etc.
-    tooltip = 'Exit the application'
+    tooltip = "Exit the application"
 
     ###########################################################################
     # 'Action' interface.
@@ -41,5 +42,3 @@ class ExitAction(Action):
         self.window.application.exit()
 
         return
-
-#### EOF ######################################################################
